Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/configuraptor/__about__.py | 1 | 0 | 0 | 100%
src/configuraptor/__init__.py | 11 | 0 | 0 | 100%
src/configuraptor/abs.py | 27 | 0 | 0 | 100%
src/configuraptor/alias.py | 17 | 0 | 0 | 100%
src/configuraptor/beautify.py | 22 | 0 | 0 | 100%
src/configuraptor/binary_config.py | 108 | 0 | 0 | 100%
src/configuraptor/cls.py | 87 | 0 | 0 | 100%
src/configuraptor/core.py | 219 | 0 | 10 | 100%
src/configuraptor/dump.py | 47 | 0 | 2 | 100%
src/configuraptor/errors.py | 53 | 0 | 0 | 100%
src/configuraptor/helpers.py | 67 | 0 | 0 | 100%
src/configuraptor/loaders/__init__.py | 17 | 0 | 0 | 100%
src/configuraptor/loaders/_types.py | 4 | 0 | 0 | 100%
src/configuraptor/loaders/loaders_shared.py | 48 | 0 | 0 | 100%
src/configuraptor/loaders/register.py | 40 | 0 | 0 | 100%
src/configuraptor/postpone.py | 19 | 0 | 2 | 100%
src/configuraptor/singleton.py | 13 | 0 | 0 | 100%
src/configuraptor/type_converters.py | 33 | 0 | 0 | 100%
Total | 833 | 0 | 14 | 100%

No items found using the specified filter.